@@ -6,6 +6,10 @@ import json
 import sys
 import importlib
 from spotPython.hyperparameters.values import get_tuned_architecture
+import pprint
+from spotPython.utils.eda import gen_design_table
+from spotPython.utils.tensorboard import start_tensorboard, stop_tensorboard
+
 
 # from torch.utils.tensorboard import SummaryWriter
 
@@ -216,3 +220,33 @@ def get_experiment_from_PREFIX(PREFIX, return_dict=True) -> dict:
         }
     else:
         return config, fun_control, design_control, surrogate_control, optimizer_control
+
+
+def load_and_run_spot_python_experiment(spot_pkl_name) -> tuple:
+    """Loads and runs a spot experiment.
+
+    Args:
+        spot_pkl_name (str):
+            The name of the spot experiment file.
+
+    Returns:
+        tuple: A tuple containing the spot tuner, fun control,
+               design control, surrogate control, optimizer control,
+               and the tensorboard process
+
+    Examples:
+        >>> from spotPython.utils.file import load_and_run_spot_python_experiment
+        >>> spot_tuner = load_and_run_spot_python_experiment("spot_branin_experiment.pickle")
+
+    """
+    p_open = None
+    (spot_tuner, fun_control, design_control, surrogate_control, optimizer_control) = load_experiment(spot_pkl_name)
+    print("\nLoaded fun_control in spotRun():")
+    pprint.pprint(fun_control)
+    print(gen_design_table(fun_control))
+    p_open = start_tensorboard()
+    spot_tuner.run()
+    spot_tuner.save_experiment()
+    # tensorboard --logdir="runs/"
+    stop_tensorboard(p_open)
+    return spot_tuner, fun_control, design_control, surrogate_control, optimizer_control, p_open
