@@ -3,6 +3,7 @@ from spotPython.fun.objectivefunctions import analytical
 from spotPython.spot import spot
 from spotPython.utils.init import fun_control_init, design_control_init
 
+
 def test_get_new_X0():
     # number of initial points:
     ni = 3
@@ -11,24 +12,20 @@ def test_get_new_X0():
     fun = analytical().fun_sphere
 
     fun_control = fun_control_init(
-            sigma=0.0,
-            seed=123,
-            lower = np.array([-1, -1]),
-            upper= np.array([1, 1]),
-            noise=False,
-            fun_repeats=1,
-            n_points=10,
-            ocba_delta=0,
-            show_progress=True
+        sigma=0.0,
+        seed=123,
+        lower=np.array([-1, -1]),
+        upper=np.array([1, 1]),
+        noise=False,
+        fun_repeats=1,
+        n_points=10,
+        ocba_delta=0,
+        show_progress=True,
     )
 
-    design_control=design_control_init(init_size=ni,
-                                       repeats=1)
+    design_control = design_control_init(init_size=ni, repeats=1)
 
-    S = spot.Spot(fun=fun,
-                  fun_control=fun_control,
-                  design_control=design_control
-    )
+    S = spot.Spot(fun=fun, fun_control=fun_control, design_control=design_control)
     S.initialize_design(X_start=X_start)
     S.update_stats()
     S.fit_surrogate()
