@@ -1,4 +1,3 @@
-import pytest
 from spotPython.utils.init import fun_control_init
 from spotPython.light.regression.netlightregression import NetLightRegression
 from spotPython.hyperdict.light_hyper_dict import LightHyperDict
@@ -10,7 +9,7 @@ import spotPython.light.testmodel as tm
 
 
 def test_testmodel():
-    fun_control = fun_control_init(_L_in=10, _L_out=1, _torchmetric="mean_squared_error")
+    fun_control = fun_control_init(_L_in=10, _L_out=1, _torchmetric="mean_squared_error", accelerator="cpu")
 
     dataset = Diabetes()
     set_control_key_value(control_dict=fun_control, key="data_set", value=dataset, replace=True)
@@ -24,7 +23,3 @@ def test_testmodel():
         break
     # check if y is a float
     assert isinstance(y_test[0], float)
-
-
-if __name__ == "__main__":
-    pytest.main(["-v", __file__])
